@@ -46,15 +46,14 @@ def cli() -> None:
     # Remove zxpy executable from argv
     sys.argv = sys.argv[1:]
 
-    filenames = sys.argv
-    if not filenames:
+    if len(sys.argv) == 0:
         setup_zxpy_repl()
         return
 
-    for filename in filenames:
-        with open(filename) as file:
-            module = ast.parse(file.read())
-            run_zxpy(filename, module)
+    filename = sys.argv[0]
+    with open(filename) as file:
+        module = ast.parse(file.read())
+        run_zxpy(filename, module)
 
 
 @overload
@@ -117,7 +116,16 @@ def run_shell_alternate(command: str) -> Tuple[str, str, int]:
 def run_zxpy(filename: str, module: ast.Module) -> None:
     """Runs zxpy on a given file"""
     patch_shell_commands(module)
-    exec(compile(module, filename, mode='exec'))
+    code = compile(module, filename, mode='exec')
+    exec(
+        code,
+        {
+            '__name__': '__main__',
+            'run_shell': run_shell,
+            'run_shell_alternate': run_shell_alternate,
+            'shlex_quote': shlex_quote,
+        },
+    )
 
 
 def patch_shell_commands(module: Union[ast.Module, ast.Interactive]) -> None:
